@@ -14,9 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
-from calculate.consolegui import qt
+from .. import qt
 import urllib.request as urllib2
 
 from .DisplayMethod import DisplayMethod, StartWidget, ConnectLostLabel
@@ -36,8 +34,8 @@ from .CertificateClass import CertClass
 from .pid_information import client_list_pid
 from .more import icon_visible, client_del_sid, show_msg, get_icon
 
-DEBUG_LEVEL = 0
-
+# DEBUG_LEVEL = 0
+DEBUG_LEVEL = 99999
 
 def debug(level, *args):
     if level <= DEBUG_LEVEL:
